<h1 align="center">
  <br>
  <a href="https://discord.gg/VMF4zSt8y5"><img src="https://cdn.discordapp.com/icons/873910232072466432/29edfa83a3c1c808cbac45f919751612.png?size=128" width="150"></a>
  <br>
</h1>

## More Info About Use -> [The Code Discord](https://discord.com/channels/804774474444046407/810877242200686654)

### What is this lib?
Python API to easily connect Amino servers

### How to install?
`pip install SAmino`
- **FOCUS!:** type `SAmino` **Not** `Amino`

### API Reference documentation
Soon...

Powered By [S-Amino](http://aminoapps.com/c/S-Aminos) Community!
SirLez, A7rf, Texaz, Bovonos
